@@ -505,7 +505,12 @@ class RequestHandlerComponent extends Component {
  *   in the request content type will be returned.
  */
 	public function requestedWith($type = null) {
-		if (!$this->request->is('post') && !$this->request->is('put') && !$this->request->is('delete')) {
+		if (
+			!$this->request->is('patch') &&
+			!$this->request->is('post') &&
+			!$this->request->is('put') &&
+			!$this->request->is('delete')
+		) {
 			return null;
 		}
 		if (is_array($type)) {
