@@ -140,7 +140,7 @@ class TranslateBehavior extends ModelBehavior {
 			unset($this->_joinTable, $this->_runtimeModel);
 			return $query;
 		} elseif (is_string($query['fields'])) {
-			$query['fields'] = String::tokenize($query['fields']);
+			$query['fields'] = CakeText::tokenize($query['fields']);
 		}
 
 		$fields = array_merge(
