@@ -2120,6 +2120,21 @@ class Uuid extends CakeTestModel {
 	public $name = 'Uuid';
 }
 
+/**
+ * UuidNative class
+ *
+ * @package       Cake.Test.Case.Model
+ */
+class UuidNative extends CakeTestModel {
+
+/**
+ * name property
+ *
+ * @var string
+ */
+	public $name = 'UuidNative';
+}
+
 /**
  * DataTest class
  *
@@ -3055,6 +3070,84 @@ class UuiditemsUuidportfolioNumericid extends CakeTestModel {
 	public $name = 'UuiditemsUuidportfolioNumericid';
 }
 
+/**
+ * Uuidnativeportfolio class
+ *
+ * @package       Cake.Test.Case.Model
+ */
+class Uuidnativeportfolio extends CakeTestModel {
+
+/**
+ * name property
+ *
+ * @var string
+ */
+	public $name = 'Uuidnativeportfolio';
+
+/**
+ * hasAndBelongsToMany property
+ *
+ * @var array
+ */
+	public $hasAndBelongsToMany = array('Uuidnativeitem');
+}
+
+/**
+ * Uuidnativeitem class
+ *
+ * @package       Cake.Test.Case.Model
+ */
+class Uuidnativeitem extends CakeTestModel {
+
+/**
+ * name property
+ *
+ * @var string
+ */
+	public $name = 'Uuidnativeitem';
+
+/**
+ * hasAndBelongsToMany property
+ *
+ * @var array
+ */
+	public $hasAndBelongsToMany = array(
+		'Uuidnativeportfolio' => array(
+			'with' => 'UuidnativeitemsUuidnativeportfolioNumericid'
+	));
+
+}
+
+/**
+ * UuidnativeitemsUuidnativeportfolio class
+ *
+ * @package       Cake.Test.Case.Model
+ */
+class UuidnativeitemsUuidnativeportfolio extends CakeTestModel {
+
+/**
+ * name property
+ *
+ * @var string
+ */
+	public $name = 'UuidnativeitemsUuidnativeportfolio';
+}
+
+/**
+ * UuidnativeitemsPortfolioNumericid class
+ *
+ * @package       Cake.Test.Case.Model
+ */
+class UuidnativeitemsUuidnativeportfolioNumericid extends CakeTestModel {
+
+/**
+ * name property
+ *
+ * @var string
+ */
+	public $name = 'UuidnativeitemsUuidnativeportfolioNumericid';
+}
+
 /**
  * TranslateTestModel class.
  *
@@ -4781,7 +4874,6 @@ class MysqlTestModel extends Model {
 
 /**
  * Test model for datasource prefixes
- *
  */
 class PrefixTestModel extends CakeTestModel {
 }
