@@ -465,7 +465,7 @@ class Hash {
 		$count = count($paths);
 
 		if (!$count) {
-			return;
+			return null;
 		}
 
 		for ($i = 0; $i < $count; $i++) {
@@ -824,7 +824,7 @@ class Hash {
 	}
 
 /**
- * Sorts an array by any value, determined by a Set-compatible path
+ * Sorts an array by any value, determined by a Hash-compatible path
  *
  * ### Sort directions
  *
@@ -839,10 +839,19 @@ class Hash {
  * - `natural` Compare items as strings using "natural ordering" in a human friendly way.
  *   Will sort foo10 below foo2 as an example. Requires PHP 5.4 or greater or it will fallback to 'regular'
  *
+ * To do case insensitive sorting, pass the type as an array as follows:
+ *
+ * ```
+ * array('type' => 'regular', 'ignoreCase' => true)
+ * ```
+ *
+ * When using the array form, `type` defaults to 'regular'. The `ignoreCase` option
+ * defaults to `false`.
+ *
  * @param array $data An array of data to sort
- * @param string $path A Set-compatible path to the array value
+ * @param string $path A Hash-compatible path to the array value
  * @param string $dir See directions above. Defaults to 'asc'.
- * @param string $type See direction types above. Defaults to 'regular'.
+ * @param array|string $type See direction types above. Defaults to 'regular'.
  * @return array Sorted array of data
  * @link http://book.cakephp.org/2.0/en/core-utility-libraries/hash.html#Hash::sort
  */
@@ -869,10 +878,21 @@ class Hash {
 		$values = static::extract($result, '{n}.value');
 
 		$dir = strtolower($dir);
-		$type = strtolower($type);
+		$ignoreCase = false;
+
+		// $type can be overloaded for case insensitive sort
+		if (is_array($type)) {
+			$type += array('ignoreCase' => false, 'type' => 'regular');
+			$ignoreCase = $type['ignoreCase'];
+			$type = $type['type'];
+		} else {
+			$type = strtolower($type);
+		}
+
 		if ($type === 'natural' && version_compare(PHP_VERSION, '5.4.0', '<')) {
 			$type = 'regular';
 		}
+
 		if ($dir === 'asc') {
 			$dir = SORT_ASC;
 		} else {
@@ -887,7 +907,12 @@ class Hash {
 		} else {
 			$type = SORT_REGULAR;
 		}
-		array_multisort($values, $dir, $type, $keys, $dir, $type);
+
+		if ($ignoreCase) {
+			$values = array_map('mb_strtolower', $values);
+		}
+		array_multisort($values, $dir, $type, $keys, $dir);
+
 		$sorted = array();
 		$keys = array_unique($keys);
 
